# model_library_public
Public version of the model library. This repository serves as a submodule of [Brian2Lava](https://gitlab.com/brian2lava/brian2lava). 

Note that the repository of the full model library, which includes Loihi 2 process models, is restricted in access due to legal regulations. Pushes to this public repository only ought to happen from the full model library.
